/// <reference types="mapbox-gl" />
import * as React from 'react';
import { MapboxProps } from '../mapbox/mapbox';
import { MapRef } from '../mapbox/create-ref';
import type { CSSProperties } from 'react';
import type { MapboxMap } from '../types';
export declare const MapContext: React.Context<MapboxMap>;
export declare type MapProps = MapboxProps & {
    /** Map container id */
    id?: string;
    /** Map container CSS style */
    style?: CSSProperties;
    children?: any;
};
declare const Map: React.ForwardRefExoticComponent<import("../types").ViewState & {
    mapboxAccessToken?: string;
    initialViewState?: import("../types").ViewState & {
        bounds?: import("mapbox-gl").LngLatBoundsLike;
        fitBoundsOptions?: import("mapbox-gl").FitBoundsOptions;
    };
    gl?: WebGLRenderingContext;
    antialias?: boolean;
    attributionControl?: boolean;
    bearingSnap?: number;
    clickTolerance?: number;
    collectResourceTiming?: boolean;
    cooperativeGestures?: boolean;
    crossSourceCollisions?: boolean;
    customAttribution?: string | string[];
    fadeDuration?: number;
    failIfMajorPerformanceCaveat?: boolean;
    hash?: string | boolean;
    interactive?: boolean;
    locale?: {
        [key: string]: string;
    };
    localFontFamily?: string;
    localIdeographFontFamily?: string;
    logoPosition?: "top-left" | "top-right" | "bottom-left" | "bottom-right";
    maxTileCacheSize?: number;
    optimizeForTerrain?: boolean;
    pitchWithRotate?: boolean;
    preserveDrawingBuffer?: boolean;
    refreshExpiredTiles?: boolean;
    testMode?: boolean;
    trackResize?: boolean;
    transformRequest?: import("mapbox-gl").TransformRequestFunction;
    boxZoom?: boolean;
    doubleClickZoom?: boolean;
    dragPan?: boolean | import("mapbox-gl").DragPanOptions;
    dragRotate?: boolean;
    keyboard?: boolean;
    scrollZoom?: boolean | import("mapbox-gl").InteractiveOptions;
    touchPitch?: boolean | import("mapbox-gl").InteractiveOptions;
    touchZoomRotate?: boolean | import("mapbox-gl").InteractiveOptions;
    maxBounds?: import("mapbox-gl").LngLatBoundsLike;
    maxPitch?: number;
    maxZoom?: number;
    minPitch?: number;
    minZoom?: number;
    viewState?: import("../types").ViewState;
    mapStyle?: string | import("mapbox-gl").Style | import("../types").ImmutableLike;
    styleDiffing?: boolean;
    interactiveLayerIds?: string[];
    projection?: string | import("../types").ProjectionSpecification;
    renderWorldCopies?: boolean;
    cursor?: string;
    onMouseDown?: (e: import("mapbox-gl").MapLayerMouseEvent) => void;
    onMouseUp?: (e: import("mapbox-gl").MapLayerMouseEvent) => void;
    onMouseOver?: (e: import("mapbox-gl").MapLayerMouseEvent) => void;
    onMouseMove?: (e: import("mapbox-gl").MapLayerMouseEvent) => void;
    onClick?: (e: import("mapbox-gl").MapLayerMouseEvent) => void;
    onDblClick?: (e: import("mapbox-gl").MapLayerMouseEvent) => void;
    onMouseEnter?: (e: import("mapbox-gl").MapLayerMouseEvent) => void;
    onMouseLeave?: (e: import("mapbox-gl").MapLayerMouseEvent) => void;
    onMouseOut?: (e: import("mapbox-gl").MapLayerMouseEvent) => void;
    onContextMenu?: (e: import("mapbox-gl").MapLayerMouseEvent) => void;
    onWheel?: (e: import("mapbox-gl").MapWheelEvent) => void;
    onTouchStart?: (e: import("mapbox-gl").MapLayerTouchEvent) => void;
    onTouchEnd?: (e: import("mapbox-gl").MapLayerTouchEvent) => void;
    onTouchMove?: (e: import("mapbox-gl").MapLayerTouchEvent) => void;
    onTouchCancel?: (e: import("mapbox-gl").MapLayerTouchEvent) => void;
    onMoveStart?: (e: import("../types").ViewStateChangeEvent) => void;
    onMove?: (e: import("../types").ViewStateChangeEvent) => void;
    onMoveEnd?: (e: import("../types").ViewStateChangeEvent) => void;
    onDragStart?: (e: import("../types").ViewStateChangeEvent) => void;
    onDrag?: (e: import("../types").ViewStateChangeEvent) => void;
    onDragEnd?: (e: import("../types").ViewStateChangeEvent) => void;
    onZoomStart?: (e: import("../types").ViewStateChangeEvent) => void;
    onZoom?: (e: import("../types").ViewStateChangeEvent) => void;
    onZoomEnd?: (e: import("../types").ViewStateChangeEvent) => void;
    onRotateStart?: (e: import("../types").ViewStateChangeEvent) => void;
    onRotate?: (e: import("../types").ViewStateChangeEvent) => void;
    onRotateEnd?: (e: import("../types").ViewStateChangeEvent) => void;
    onPitchStart?: (e: import("../types").ViewStateChangeEvent) => void;
    onPitch?: (e: import("../types").ViewStateChangeEvent) => void;
    onPitchEnd?: (e: import("../types").ViewStateChangeEvent) => void;
    onBoxZoomStart?: (e: import("../types").ViewStateChangeEvent) => void;
    onBoxZoomEnd?: (e: import("../types").ViewStateChangeEvent) => void;
    onBoxZoomCancel?: (e: import("../types").ViewStateChangeEvent) => void;
    onResize?: (e: import("mapbox-gl").MapboxEvent<undefined>) => void;
    onLoad?: (e: import("mapbox-gl").MapboxEvent<undefined>) => void;
    onRender?: (e: import("mapbox-gl").MapboxEvent<undefined>) => void;
    onIdle?: (e: import("mapbox-gl").MapboxEvent<undefined>) => void;
    onError?: (e: import("mapbox-gl").ErrorEvent) => void;
    onRemove?: (e: import("mapbox-gl").MapboxEvent<undefined>) => void;
    onData?: (e: import("mapbox-gl").MapDataEvent) => void;
    onStyleData?: (e: import("mapbox-gl").MapDataEvent) => void;
    onSourceData?: (e: import("mapbox-gl").MapDataEvent) => void;
} & {
    /** Map container id */
    id?: string;
    /** Map container CSS style */
    style?: CSSProperties;
    children?: any;
} & React.RefAttributes<MapRef>>;
export default Map;
