"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MapContext = void 0;
var React = require("react");
var react_1 = require("react");
var use_map_1 = require("./use-map");
var mapboxgl_1 = require("../utils/mapboxgl");
var mapbox_1 = require("../mapbox/mapbox");
var create_ref_1 = require("../mapbox/create-ref");
var use_isomorphic_layout_effect_1 = require("../utils/use-isomorphic-layout-effect");
exports.MapContext = React.createContext(null);
var defaultProps = {
    // Constraints
    minZoom: 0,
    maxZoom: 22,
    minPitch: 0,
    maxPitch: 85,
    // Interaction handlers
    scrollZoom: true,
    boxZoom: true,
    dragRotate: true,
    dragPan: true,
    keyboard: true,
    doubleClickZoom: true,
    touchZoomRotate: true,
    touchPitch: true,
    // Style
    mapStyle: { version: 8 },
    styleDiffing: true,
    projection: 'mercator',
    renderWorldCopies: true
};
var Map = (0, react_1.forwardRef)(function (props, ref) {
    var mountedMapsContext = (0, react_1.useContext)(use_map_1.MountedMapsContext);
    var _a = (0, react_1.useState)(null), mapInstance = _a[0], setMapInstance = _a[1];
    var containerRef = (0, react_1.useRef)();
    (0, react_1.useEffect)(function () {
        var map = new mapbox_1.default(mapboxgl_1.default.Map, props);
        map.initialize(containerRef.current);
        setMapInstance(map);
        mountedMapsContext === null || mountedMapsContext === void 0 ? void 0 : mountedMapsContext.onMapMount((0, create_ref_1.default)(map), props.id);
        return function () {
            mountedMapsContext === null || mountedMapsContext === void 0 ? void 0 : mountedMapsContext.onMapUnmount(props.id);
            map.destroy();
        };
    }, []);
    (0, use_isomorphic_layout_effect_1.default)(function () {
        if (mapInstance) {
            mapInstance.setProps(props);
        }
    });
    (0, react_1.useImperativeHandle)(ref, function () { return (0, create_ref_1.default)(mapInstance); }, [mapInstance]);
    var style = __assign({ position: 'relative', width: '100%', height: '100%' }, props.style);
    return (React.createElement("div", { id: props.id, ref: containerRef, style: style }, mapInstance && (React.createElement(exports.MapContext.Provider, { value: mapInstance.map }, props.children))));
});
Map.displayName = 'Map';
Map.defaultProps = defaultProps;
exports.default = Map;
//# sourceMappingURL=map.js.map