"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var react_1 = require("react");
var react_2 = require("react");
var map_1 = require("./map");
var assert_1 = require("../utils/assert");
var deep_equal_1 = require("../utils/deep-equal");
var sourceCounter = 0;
function createSource(map, id, props) {
    // @ts-ignore
    if (map.style && map.style._loaded) {
        var options = __assign({}, props);
        delete options.id;
        delete options.children;
        // @ts-ignore
        map.addSource(id, options);
        return map.getSource(id);
    }
    return null;
}
/* eslint-disable complexity */
function updateSource(source, props, prevProps) {
    (0, assert_1.default)(props.id === prevProps.id, 'source id changed');
    (0, assert_1.default)(props.type === prevProps.type, 'source type changed');
    var changedKey = '';
    var changedKeyCount = 0;
    for (var key in props) {
        if (key !== 'children' && key !== 'id' && !(0, deep_equal_1.deepEqual)(prevProps[key], props[key])) {
            changedKey = key;
            changedKeyCount++;
        }
    }
    if (!changedKeyCount) {
        return;
    }
    var type = props.type;
    if (type === 'geojson') {
        source.setData(props.data);
    }
    else if (type === 'image') {
        source.updateImage({ url: props.url, coordinates: props.coordinates });
    }
    else if ((type === 'canvas' || type === 'video') &&
        changedKeyCount === 1 &&
        changedKey === 'coordinates') {
        source.setCoordinates(props.coordinates);
    }
    else if (type === 'vector' && 'setUrl' in source) {
        // Added in 1.12.0:
        // vectorTileSource.setTiles
        // vectorTileSource.setUrl
        switch (changedKey) {
            case 'url':
                source.setUrl(props.url);
                break;
            case 'tiles':
                source.setTiles(props.tiles);
                break;
            default:
        }
    }
    else {
        // eslint-disable-next-line
        console.warn("Unable to update <Source> prop: ".concat(changedKey));
    }
}
/* eslint-enable complexity */
function Source(props) {
    var map = (0, react_1.useContext)(map_1.MapContext);
    var propsRef = (0, react_1.useRef)(props);
    var _a = (0, react_1.useState)(0), setStyleLoaded = _a[1];
    var id = (0, react_1.useMemo)(function () { return props.id || "jsx-source-".concat(sourceCounter++); }, []);
    (0, react_1.useEffect)(function () {
        if (map) {
            var forceUpdate_1 = function () { return setStyleLoaded(function (version) { return version + 1; }); };
            map.on('styledata', forceUpdate_1);
            return function () {
                map.off('styledata', forceUpdate_1);
                /* global requestAnimationFrame */
                // Do not remove source immediately because the
                // dependent <Layer>s' componentWillUnmount() might not have been called
                // Removing source before dependent layers will throw error
                // TODO - find a more robust solution
                requestAnimationFrame(function () {
                    // @ts-ignore
                    if (map.style && map.style._loaded && map.getSource(id)) {
                        map.removeSource(id);
                    }
                });
            };
        }
        return undefined;
    }, [map, id]);
    // @ts-ignore
    var source = map && map.style && map.getSource(id);
    if (source) {
        updateSource(source, props, propsRef.current);
    }
    else {
        source = createSource(map, id, props);
    }
    propsRef.current = props;
    return ((source &&
        React.Children.map(props.children, function (child) {
            return child &&
                (0, react_2.cloneElement)(child, {
                    source: id
                });
        })) ||
        null);
}
exports.default = Source;
//# sourceMappingURL=source.js.map