"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.normalizeStyle = void 0;
var refProps = ['type', 'source', 'source-layer', 'minzoom', 'maxzoom', 'filter', 'layout'];
// Prepare a map style object for diffing
// If immutable - convert to plain object
// Work around some issues in older styles that would fail Mapbox's diffing
function normalizeStyle(style) {
    if (!style) {
        return null;
    }
    if (typeof style === 'string') {
        return style;
    }
    if ('toJS' in style) {
        style = style.toJS();
    }
    var layerIndex = {};
    for (var _i = 0, _a = style.layers; _i < _a.length; _i++) {
        var layer = _a[_i];
        layerIndex[layer.id] = layer;
    }
    var layers = style.layers.map(function (layer) {
        // @ts-expect-error
        var layerRef = layerIndex[layer.ref];
        var normalizedLayer = null;
        if ('interactive' in layer) {
            normalizedLayer = __assign({}, layer);
            // Breaks style diffing :(
            delete normalizedLayer.interactive;
        }
        // Style diffing doesn't work with refs so expand them out manually before diffing.
        if (layerRef) {
            normalizedLayer = normalizedLayer || __assign({}, layer);
            delete normalizedLayer.ref;
            // https://github.com/mapbox/mapbox-gl-js/blob/master/src/style-spec/deref.js
            for (var _i = 0, refProps_1 = refProps; _i < refProps_1.length; _i++) {
                var propName = refProps_1[_i];
                if (propName in layerRef) {
                    normalizedLayer[propName] = layerRef[propName];
                }
            }
        }
        return normalizedLayer || layer;
    });
    // Do not mutate the style object provided by the user
    return __assign(__assign({}, style), { layers: layers });
}
exports.normalizeStyle = normalizeStyle;
//# sourceMappingURL=style-utils.js.map