import * as React from 'react';
import { useState, useRef, useEffect, useContext, forwardRef, useImperativeHandle } from 'react';
import { MountedMapsContext } from './use-map';
import mapboxgl from '../utils/mapboxgl';
import Mapbox from '../mapbox/mapbox';
import createRef from '../mapbox/create-ref';
import useIsomorphicLayoutEffect from '../utils/use-isomorphic-layout-effect';
export const MapContext = React.createContext(null);
const defaultProps = {
    // Constraints
    minZoom: 0,
    maxZoom: 22,
    minPitch: 0,
    maxPitch: 85,
    // Interaction handlers
    scrollZoom: true,
    boxZoom: true,
    dragRotate: true,
    dragPan: true,
    keyboard: true,
    doubleClickZoom: true,
    touchZoomRotate: true,
    touchPitch: true,
    // Style
    mapStyle: { version: 8 },
    styleDiffing: true,
    projection: 'mercator',
    renderWorldCopies: true
};
const Map = forwardRef((props, ref) => {
    const mountedMapsContext = useContext(MountedMapsContext);
    const [mapInstance, setMapInstance] = useState(null);
    const containerRef = useRef();
    useEffect(() => {
        const map = new Mapbox(mapboxgl.Map, props);
        map.initialize(containerRef.current);
        setMapInstance(map);
        mountedMapsContext?.onMapMount(createRef(map), props.id);
        return () => {
            mountedMapsContext?.onMapUnmount(props.id);
            map.destroy();
        };
    }, []);
    useIsomorphicLayoutEffect(() => {
        if (mapInstance) {
            mapInstance.setProps(props);
        }
    });
    useImperativeHandle(ref, () => createRef(mapInstance), [mapInstance]);
    const style = {
        position: 'relative',
        width: '100%',
        height: '100%',
        ...props.style
    };
    return (React.createElement("div", { id: props.id, ref: containerRef, style: style }, mapInstance && (React.createElement(MapContext.Provider, { value: mapInstance.map }, props.children))));
});
Map.displayName = 'Map';
Map.defaultProps = defaultProps;
export default Map;
//# sourceMappingURL=map.js.map