import * as React from 'react';
import { useState, useCallback, useContext } from 'react';
export const MountedMapsContext = React.createContext(null);
export const MapProvider = props => {
    const [maps, setMaps] = useState({});
    const onMapMount = useCallback((map, id = 'default') => {
        if (maps[id]) {
            throw new Error(`Multiple maps with the same id: ${id}`);
        }
        setMaps({ ...maps, [id]: map });
    }, [maps]);
    const onMapUnmount = useCallback((id = 'default') => {
        const nextMaps = { ...maps };
        delete nextMaps[id];
        setMaps(nextMaps);
    }, [maps]);
    return (React.createElement(MountedMapsContext.Provider, { value: {
            maps,
            onMapMount,
            onMapUnmount
        } }, props.children));
};
export function useMap() {
    const { maps } = useContext(MountedMapsContext);
    return maps;
}
//# sourceMappingURL=use-map.js.map