/// <reference types="mapbox-gl" />
import type { PaddingOptions, ViewState } from '../types';
/**
 * Stub for mapbox's Transform class
 * https://github.com/mapbox/mapbox-gl-js/blob/main/src/geo/transform.js
 */
export declare type Transform = {
    center: {
        lng: number;
        lat: number;
    };
    zoom: number;
    bearing: number;
    pitch: number;
    padding: PaddingOptions;
    clone: () => Transform;
    resize: (width: number, height: number) => void;
    isPaddingEqual: (value: PaddingOptions) => boolean;
};
/**
 * Capture a transform's current state
 * @param transform
 * @returns descriptor of the view state
 */
export declare function transformToViewState(tr: Transform): ViewState;
/**
 * Mutate a transform to match the given view state
 * @param transform
 * @param viewState
 * @returns true if the transform has changed
 */
export declare function applyViewStateToTransform(tr: Transform, vs: ViewState | {
    viewState: ViewState;
}): boolean;
